# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import APIResource, APIResourceList, Condition, DeleteOptions, FieldsV1, LabelSelector, LabelSelectorRequirement, ListMeta, ManagedFieldsEntry, MicroTime, ObjectMeta, OwnerReference, Patch, Preconditions, Status, StatusCause, StatusDetails, Time, WatchEvent




__all__ = ['APIResource', 'APIResourceList', 'Condition', 'DeleteOptions', 'FieldsV1', 'LabelSelector', 'LabelSelectorRequirement', 'ListMeta', 'ManagedFieldsEntry', 'MicroTime', 'ObjectMeta', 'OwnerReference', 'Patch', 'Preconditions', 'Status', 'StatusCause', 'StatusDetails', 'Time', 'WatchEvent']

