# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import APIResource, APIResourceList, FieldSelectorRequirement, FieldsV1, LabelSelectorRequirement, ManagedFieldsEntry, ObjectMeta, OwnerReference, Time




__all__ = ['APIResource', 'APIResourceList', 'FieldSelectorRequirement', 'FieldsV1', 'LabelSelectorRequirement', 'ManagedFieldsEntry', 'ObjectMeta', 'OwnerReference', 'Time']

