# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import CrossVersionObjectReference, HorizontalPodAutoscaler, HorizontalPodAutoscalerList, HorizontalPodAutoscalerSpec, HorizontalPodAutoscalerStatus




__all__ = ['CrossVersionObjectReference', 'HorizontalPodAutoscaler', 'HorizontalPodAutoscalerList', 'HorizontalPodAutoscalerSpec', 'HorizontalPodAutoscalerStatus']

