# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha1 import IPAddress, IPAddressList, IPAddressSpec, ParentReference, ServiceCIDR, ServiceCIDRList, ServiceCIDRSpec, ServiceCIDRStatus




__all__ = ['IPAddress', 'IPAddressList', 'IPAddressSpec', 'ParentReference', 'ServiceCIDR', 'ServiceCIDRList', 'ServiceCIDRSpec', 'ServiceCIDRStatus']

