# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__certificates.k8s.io__v1beta1_openapi.json

from __future__ import annotations

from dataclasses import dataclass, field
from datetime import datetime, timezone
from typing import ClassVar, List, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import Loadable
from kube_models.resource import *

from ...apimachinery.pkg.apis.meta.v1 import ListMeta, ObjectMeta


@dataclass(slots=True, kw_only=True, frozen=True)
class ClusterTrustBundleSpec(Loadable):
    trustBundle: str
    signerName: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ClusterTrustBundle(K8sResource):
    spec: ClusterTrustBundleSpec
    apiVersion: ClassVar[str] = 'certificates.k8s.io/v1beta1'
    kind: ClassVar[str] = 'ClusterTrustBundle'
    metadata: ObjectMeta = field(default_factory=ObjectMeta)
    plural_: ClassVar[str] = 'clustertrustbundles'
    is_namespaced_: ClassVar[bool] = False
    group_: ClassVar[Optional[str]] = 'certificates.k8s.io'
    patch_strategies_: ClassVar[set[PatchRequestType]] = {
        'application/apply-patch+cbor',
        'application/apply-patch+yaml',
        'application/json-patch+json',
        'application/merge-patch+json',
        'application/strategic-merge-patch+json',
    }


@dataclass(slots=True, kw_only=True, frozen=True)
class ClusterTrustBundleList(Loadable):
    items: List[ClusterTrustBundle]
    apiVersion: str = 'certificates.k8s.io/v1beta1'
    kind: str = 'ClusterTrustBundleList'
    metadata: ListMeta = field(default_factory=ObjectMeta)
