# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha1 import AllocationResult, PodScheduling, PodSchedulingList, PodSchedulingSpec, PodSchedulingStatus, ResourceClaim, ResourceClaimConsumerReference, ResourceClaimList, ResourceClaimParametersReference, ResourceClaimSchedulingStatus, ResourceClaimSpec, ResourceClaimStatus, ResourceClaimTemplate, ResourceClaimTemplateList, ResourceClaimTemplateSpec, ResourceClass, ResourceClassList, ResourceClassParametersReference




__all__ = ['AllocationResult', 'PodScheduling', 'PodSchedulingList', 'PodSchedulingSpec', 'PodSchedulingStatus', 'ResourceClaim', 'ResourceClaimConsumerReference', 'ResourceClaimList', 'ResourceClaimParametersReference', 'ResourceClaimSchedulingStatus', 'ResourceClaimSpec', 'ResourceClaimStatus', 'ResourceClaimTemplate', 'ResourceClaimTemplateList', 'ResourceClaimTemplateSpec', 'ResourceClass', 'ResourceClassList', 'ResourceClassParametersReference']

