# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import AggregationRule, ClusterRole, ClusterRoleBinding, ClusterRoleBindingList, ClusterRoleList, PolicyRule, Role, RoleBinding, RoleBindingList, RoleList, RoleRef, Subject




__all__ = ['AggregationRule', 'ClusterRole', 'ClusterRoleBinding', 'ClusterRoleBindingList', 'ClusterRoleList', 'PolicyRule', 'Role', 'RoleBinding', 'RoleBindingList', 'RoleList', 'RoleRef', 'Subject']

