# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import ControllerRevision, ControllerRevisionList, DaemonSet, DaemonSetCondition, DaemonSetList, DaemonSetSpec, DaemonSetStatus, DaemonSetUpdateStrategy, Deployment, DeploymentCondition, DeploymentList, DeploymentSpec, DeploymentStatus, DeploymentStrategy, ReplicaSet, ReplicaSetCondition, ReplicaSetList, ReplicaSetSpec, ReplicaSetStatus, RollingUpdateDaemonSet, RollingUpdateDeployment, RollingUpdateStatefulSetStrategy, StatefulSet, StatefulSetCondition, StatefulSetList, StatefulSetOrdinals, StatefulSetPersistentVolumeClaimRetentionPolicy, StatefulSetSpec, StatefulSetStatus, StatefulSetUpdateStrategy




__all__ = ['ControllerRevision', 'ControllerRevisionList', 'DaemonSet', 'DaemonSetCondition', 'DaemonSetList', 'DaemonSetSpec', 'DaemonSetStatus', 'DaemonSetUpdateStrategy', 'Deployment', 'DeploymentCondition', 'DeploymentList', 'DeploymentSpec', 'DeploymentStatus', 'DeploymentStrategy', 'ReplicaSet', 'ReplicaSetCondition', 'ReplicaSetList', 'ReplicaSetSpec', 'ReplicaSetStatus', 'RollingUpdateDaemonSet', 'RollingUpdateDeployment', 'RollingUpdateStatefulSetStrategy', 'StatefulSet', 'StatefulSetCondition', 'StatefulSetList', 'StatefulSetOrdinals', 'StatefulSetPersistentVolumeClaimRetentionPolicy', 'StatefulSetSpec', 'StatefulSetStatus', 'StatefulSetUpdateStrategy']

