# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__events.k8s.io__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import Loadable
from kube_models.resource import *


@dataclass(slots=True, kw_only=True, frozen=True)
class EventSource(Loadable):
    component: str | None = None
    host: str | None = None


@dataclass(slots=True, kw_only=True, frozen=True)
class ObjectReference(Loadable):
    apiVersion: str | None = None
    fieldPath: str | None = None
    kind: str | None = None
    name: str | None = None
    namespace: str | None = None
    resourceVersion: str | None = None
    uid: str | None = None
