# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import AllocatedDeviceStatus, AllocationResult, CELDeviceSelector, CapacityRequestPolicy, CapacityRequestPolicyRange, CapacityRequirements, Counter, CounterSet, Device, DeviceAllocationConfiguration, DeviceAllocationResult, DeviceAttribute, DeviceCapacity, DeviceClaim, DeviceClaimConfiguration, DeviceClass, DeviceClassConfiguration, DeviceClassList, DeviceClassSpec, DeviceConstraint, DeviceCounterConsumption, DeviceRequest, DeviceRequestAllocationResult, DeviceSelector, DeviceSubRequest, DeviceTaint, DeviceToleration, ExactDeviceRequest, NetworkDeviceData, OpaqueDeviceConfiguration, ResourceClaim, ResourceClaimConsumerReference, ResourceClaimList, ResourceClaimSpec, ResourceClaimStatus, ResourceClaimTemplate, ResourceClaimTemplateList, ResourceClaimTemplateSpec, ResourcePool, ResourceSlice, ResourceSliceList, ResourceSliceSpec




__all__ = ['AllocatedDeviceStatus', 'AllocationResult', 'CELDeviceSelector', 'CapacityRequestPolicy', 'CapacityRequestPolicyRange', 'CapacityRequirements', 'Counter', 'CounterSet', 'Device', 'DeviceAllocationConfiguration', 'DeviceAllocationResult', 'DeviceAttribute', 'DeviceCapacity', 'DeviceClaim', 'DeviceClaimConfiguration', 'DeviceClass', 'DeviceClassConfiguration', 'DeviceClassList', 'DeviceClassSpec', 'DeviceConstraint', 'DeviceCounterConsumption', 'DeviceRequest', 'DeviceRequestAllocationResult', 'DeviceSelector', 'DeviceSubRequest', 'DeviceTaint', 'DeviceToleration', 'ExactDeviceRequest', 'NetworkDeviceData', 'OpaqueDeviceConfiguration', 'ResourceClaim', 'ResourceClaimConsumerReference', 'ResourceClaimList', 'ResourceClaimSpec', 'ResourceClaimStatus', 'ResourceClaimTemplate', 'ResourceClaimTemplateList', 'ResourceClaimTemplateSpec', 'ResourcePool', 'ResourceSlice', 'ResourceSliceList', 'ResourceSliceSpec']

