# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import JobSpec
from .v1beta1 import CronJob, CronJobList, CronJobSpec, CronJobStatus, JobTemplateSpec




__all__ = ['JobSpec', 'CronJob', 'CronJobList', 'CronJobSpec', 'CronJobStatus', 'JobTemplateSpec']

