# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import APIGroup, APIGroupList, GroupVersionForDiscovery, ServerAddressByClientCIDR




__all__ = ['APIGroup', 'APIGroupList', 'GroupVersionForDiscovery', 'ServerAddressByClientCIDR']

