# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__resource.k8s.io__v1beta1_openapi.json

from __future__ import annotations

from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import Loadable
from kube_models.resource import *

Quantity = str | float
